# Face Track

## Key Features

* Tracks your face
* Quick and not much lag
* Simple code that is easy to understand and customize if needed

## License

MIT

---

> [http://advaith.athenaserv.com](http://advaith.athenaserv.com) &nbsp;&middot;&nbsp;
> GitHub [@advaith-22](https://github.com/advaith-22) &nbsp;&middot;&nbsp;
> Twitter [@_Advaith_S](https://twitter.com/_Advaith_S)
